==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_subnet_bandwidth_control_list_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSubnetBandwidthControlListResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'control_mode': 'str',
        'control_list': 'list[ControlItem]',
        'total_count': 'int'
    }

    attribute_map = {
        'control_mode': 'control_mode',
        'control_list': 'control_list',
        'total_count': 'total_count'
    }

    def __init__(self, control_mode=None, control_list=None, total_count=None):
        """ShowSubnetBandwidthControlListResponse

        The model defined in huaweicloud sdk

        :param control_mode: 控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。
        :type control_mode: str
        :param control_list: 控制的桌面列表。
        :type control_list: list[:class:`huaweicloudsdkworkspace.v2.ControlItem`]
        :param total_count: 总数。
        :type total_count: int
        """
        
        super(ShowSubnetBandwidthControlListResponse, self).__init__()

        self._control_mode = None
        self._control_list = None
        self._total_count = None
        self.discriminator = None

        if control_mode is not None:
            self.control_mode = control_mode
        if control_list is not None:
            self.control_list = control_list
        if total_count is not None:
            self.total_count = total_count

    @property
    def control_mode(self):
        """Gets the control_mode of this ShowSubnetBandwidthControlListResponse.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :return: The control_mode of this ShowSubnetBandwidthControlListResponse.
        :rtype: str
        """
        return self._control_mode

    @control_mode.setter
    def control_mode(self, control_mode):
        """Sets the control_mode of this ShowSubnetBandwidthControlListResponse.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :param control_mode: The control_mode of this ShowSubnetBandwidthControlListResponse.
        :type control_mode: str
        """
        self._control_mode = control_mode

    @property
    def control_list(self):
        """Gets the control_list of this ShowSubnetBandwidthControlListResponse.

        控制的桌面列表。

        :return: The control_list of this ShowSubnetBandwidthControlListResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.ControlItem`]
        """
        return self._control_list

    @control_list.setter
    def control_list(self, control_list):
        """Sets the control_list of this ShowSubnetBandwidthControlListResponse.

        控制的桌面列表。

        :param control_list: The control_list of this ShowSubnetBandwidthControlListResponse.
        :type control_list: list[:class:`huaweicloudsdkworkspace.v2.ControlItem`]
        """
        self._control_list = control_list

    @property
    def total_count(self):
        """Gets the total_count of this ShowSubnetBandwidthControlListResponse.

        总数。

        :return: The total_count of this ShowSubnetBandwidthControlListResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ShowSubnetBandwidthControlListResponse.

        总数。

        :param total_count: The total_count of this ShowSubnetBandwidthControlListResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSubnetBandwidthControlListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_subnet_bandwidth_control_list_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSubnetBandwidthControlListResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'control_mode': 'str',
        'control_list': 'list[ControlItem]',
        'total_count': 'int'
    }

    attribute_map = {
        'control_mode': 'control_mode',
        'control_list': 'control_list',
        'total_count': 'total_count'
    }

    def __init__(self, control_mode=None, control_list=None, total_count=None):
        r"""ShowSubnetBandwidthControlListResponse

        The model defined in huaweicloud sdk

        :param control_mode: 控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。
        :type control_mode: str
        :param control_list: 控制的桌面列表。
        :type control_list: list[:class:`huaweicloudsdkworkspace.v2.ControlItem`]
        :param total_count: 总数。
        :type total_count: int
        """
        
        super(ShowSubnetBandwidthControlListResponse, self).__init__()

        self._control_mode = None
        self._control_list = None
        self._total_count = None
        self.discriminator = None

        if control_mode is not None:
            self.control_mode = control_mode
        if control_list is not None:
            self.control_list = control_list
        if total_count is not None:
            self.total_count = total_count

    @property
    def control_mode(self):
        r"""Gets the control_mode of this ShowSubnetBandwidthControlListResponse.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :return: The control_mode of this ShowSubnetBandwidthControlListResponse.
        :rtype: str
        """
        return self._control_mode

    @control_mode.setter
    def control_mode(self, control_mode):
        r"""Sets the control_mode of this ShowSubnetBandwidthControlListResponse.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :param control_mode: The control_mode of this ShowSubnetBandwidthControlListResponse.
        :type control_mode: str
        """
        self._control_mode = control_mode

    @property
    def control_list(self):
        r"""Gets the control_list of this ShowSubnetBandwidthControlListResponse.

        控制的桌面列表。

        :return: The control_list of this ShowSubnetBandwidthControlListResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.ControlItem`]
        """
        return self._control_list

    @control_list.setter
    def control_list(self, control_list):
        r"""Sets the control_list of this ShowSubnetBandwidthControlListResponse.

        控制的桌面列表。

        :param control_list: The control_list of this ShowSubnetBandwidthControlListResponse.
        :type control_list: list[:class:`huaweicloudsdkworkspace.v2.ControlItem`]
        """
        self._control_list = control_list

    @property
    def total_count(self):
        r"""Gets the total_count of this ShowSubnetBandwidthControlListResponse.

        总数。

        :return: The total_count of this ShowSubnetBandwidthControlListResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ShowSubnetBandwidthControlListResponse.

        总数。

        :param total_count: The total_count of this ShowSubnetBandwidthControlListResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSubnetBandwidthControlListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
